# Getting started

After reviewing the [.](./ "mention"), you can sign up for a Launchable account at [https://app.launchableinc.com/signup](https://app.launchableinc.com/signup).

After creating your user account and verifying your email address (if necessary), you'll be prompted to create an [organization.md](concepts/organization.md "mention") for your company and a [workspace.md](concepts/workspace.md "mention")for your test suite.

Then you can start [sending-data-to-launchable](sending-data-to-launchable/ "mention")!
